==> abcl-0.0.9.tar.gz: abcl-0.0.9/src/org/armedbear/lisp/make_socket.java <==
/*
 * make_socket.java
 *
 * Copyright (C) 2004 Peter Graves
 * $Id: make_socket.java,v 1.3 2004/11/03 15:27:24 piso Exp $
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.armedbear.lisp;

import java.net.Socket;

// ### %make-socket
public final class make_socket extends Primitive
{
    private make_socket()
    {
        super("%make-socket", PACKAGE_SYS, false, "host port");
    }

    public LispObject execute(LispObject first, LispObject second)
        throws ConditionThrowable
    {
        String host = first.getStringValue();
        int port = Fixnum.getValue(second);
        try {
            Socket socket = new Socket(host, port);
            return new JavaObject(socket);
        }
        catch (Exception e) {
            return signal(new LispError(e.getMessage()));
        }
    }

    private static final Primitive MAKE_SOCKET = new make_socket();
}

==> abcl-0.0.10.tar.gz: abcl-0.0.10/src/org/armedbear/lisp/make_socket.java <==
/*
 * make_socket.java
 *
 * Copyright (C) 2004 Peter Graves
 * $Id: make_socket.java,v 1.4 2007/02/23 21:17:36 piso Exp $
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package org.armedbear.lisp;

import java.net.Socket;

// ### %make-socket
public final class make_socket extends Primitive
{
    private make_socket()
    {
        super("%make-socket", PACKAGE_SYS, false, "host port");
    }

    public LispObject execute(LispObject first, LispObject second)
        throws ConditionThrowable
    {
        String host = first.getStringValue();
        int port = Fixnum.getValue(second);
        try {
            Socket socket = new Socket(host, port);
            return new JavaObject(socket);
        }
        catch (Exception e) {
            return error(new LispError(e.getMessage()));
        }
    }

    private static final Primitive MAKE_SOCKET = new make_socket();
}
